@@ -2,4 +2,6 @@ from .base_schemas import VersionedXeDoc, XeDoc
 from .bodega import Bodega
 from .fax import FaxConfig
 from .corrections import *
-from .calibrations import *
\ No newline at end of file
+from .calibrations import *
+from .operations_reports import *
+from .analysis import *
\ No newline at end of file
