@@ -6,12 +6,12 @@
 
 import rframe
 
-from .base_corrections import TimeIntervalCorrection, TimeSampledCorrection
+from .base_corrections import TimeSampledCorrection
+from ..constants import DETECTOR
 
-
-class HitThreshold(TimeIntervalCorrection):
+class HitThreshold(TimeSampledCorrection):
     _ALIAS = "hit_thresholds"
-    detector: str = rframe.Index()
+    detector: DETECTOR = rframe.Index()
     pmt: int = rframe.Index()
 
     value: int
